@@ -129,8 +129,8 @@ class QtBaseDialog(BaseDialog):
         
       else:
         self.current_radio_group = None
-        if stock and (not image) and qtgui.QIcon.hasThemeIcon(stock):
-          image = qtgui.QIcon.fromTheme(stock)
+        if isinstance(stock, qtgui.QIcon):                              image = stock
+        elif stock and (not image) and qtgui.QIcon.hasThemeIcon(stock): image = qtgui.QIcon.fromTheme(stock)
         if image: action.setIcon(image)
         if command: action.triggered.connect(command2)
         
@@ -199,14 +199,20 @@ class QtEditorTabbedDialog(EditorTabbedDialog, QtBaseDialog):
 
   # For updating the childhood pane layout
   def on_tab_changed(self, index):
-    self.notebook.widget(index).hi_box.layout().invalidate()
+    editor_pane = self.notebook.widget(index)
+    self.show_tab(editor_pane)
+    editor_pane.hi_box.layout().invalidate()
+    
   def show(self):
     QtBaseDialog.show(self)
-    widget = self.notebook.currentWidget()
-    if widget: widget.hi_box.layout().invalidate()
-    
-  def add_tab(self, name, label, o = None):
+    editor_pane = self.notebook.currentWidget()
+    if editor_pane:
+      self.show_tab(editor_pane)
+      editor_pane.hi_box.layout().invalidate()
+      
+  def add_tab(self, name, label, o = None, func = None):
     editor_pane = super().add_tab(name, label, o)
+    editor_pane.func = func
     self.notebook.addTab(editor_pane, label)
     return editor_pane
   
@@ -489,7 +495,7 @@ class QtChildhoodPane(ChildhoodPane, qtwidgets.QWidget):
     #self.button_add      .setIconSize(icon_size)
     #self.button_remove   .setIconSize(icon_size)
     #self.button_move_down.setIconSize(icon_size)
-
+    
     layout = qtwidgets.QVBoxLayout()
     layout.setContentsMargins(0, 0, 0, 0)
     layout.addWidget(self.button_move_up)
@@ -677,17 +683,17 @@ class Qt_HierarchyNode(HierarchyNode, DynamicNode):
     else:                                                 attr_label = ""
     if attr_label: return '''%s : %s''' % (attr_label, self.descr.label_for(self.o))
     return self.descr.label_for(self.o)
-      
+  
 # class HierarchyScrollBar(qtwidgets.QScrollBar):
 #   def __init__(self, hierarchy_pane):
 #     qtwidgets.QScrollBar.__init__(self, qtcore.Qt.Vertical)
 #     self.hierarchy_pane = hierarchy_pane
-    
+
 #   def hideEvent(self, event):
 #     qtwidgets.QScrollBar.hideEvent(self, event)
 #     print("cachée")
 #     #self..overlay_offset_x = 3
-    
+
 #   def showEvent(self, event):
 #     qtwidgets.QScrollBar.showEvent(self, event)
 #     print("visible")
@@ -730,7 +736,7 @@ class QtHierarchyPane(HierarchyPane, qtwidgets.QTreeView):
     self.setModel(self.tree)
     self.selectionModel().selectionChanged.connect(self.on_selection_changed)
     if self.flat_list:
-      self.childhood_pane.edit(None, None, self.o)
+      self.childhood_pane.edit(self.childhood_pane_parent, self.childhood_pane_attribute, self.o)
     else:
       self.setExpanded(self.root_node.qt_index(), True)
       self.selectionModel().select(self.root_node.qt_index(), qtcore.QItemSelectionModel.ClearAndSelect)
@@ -740,7 +746,7 @@ class QtHierarchyPane(HierarchyPane, qtwidgets.QTreeView):
   def select_node(self, node):
     self.selectionModel().clearSelection()
     if   node:                                   self.selectionModel().select(node.qt_index(), qtcore.QItemSelectionModel.Select)
-    elif self.flat_list and self.childhood_pane: self.childhood_pane.edit(None, None, self.o)
+    elif self.flat_list and self.childhood_pane: self.childhood_pane.edit(self.childhood_pane_parent, self.childhood_pane_attribute, self.o)
     
   def on_collapsed(self, index):
     node = index.internalPointer()
@@ -762,7 +768,7 @@ class QtHierarchyPane(HierarchyPane, qtwidgets.QTreeView):
     indexes = self.selectionModel().selectedIndexes()
     if len(indexes) == 0:
       self.edit_child(None)
-      if self.childhood_pane: self.childhood_pane.edit(None, None, None)
+      if self.childhood_pane: self.childhood_pane.edit(self.childhood_pane_parent, self.childhood_pane_attribute, None)
       self.selected_node = None
       return
     
@@ -785,8 +791,12 @@ class QtHierarchyPane(HierarchyPane, qtwidgets.QTreeView):
       self.edit_child(self.selected, self.get_ignored_attrs(nodes))
       if self.childhood_pane: self.childhood_pane.edit(self.selected_parent, self.selected_attribute, self.selected)
       
-  def on_action_activated(self, action): self._action_activated(action, self.selected_parent, self.selected_attribute, self.selected)
-  
+  def on_action_activated(self, action):
+    if self.selected:
+      self._action_activated(action, self.selected_parent, self.selected_attribute, self.selected)
+    else:
+      self._action_activated(action, None, self.restrict_to_attribute, self.o)
+      
   def show_action_menu(self, actions):
     self._popup_menu = qtwidgets.QMenu() # The menu must be kept in memory, else it does not appear.
     for action in actions:
