@@ -26,6 +26,14 @@ import os, os.path, types, inspect, locale
 import editobj3, editobj3.undoredo as undoredo
 from collections import defaultdict
 
+_entity_classes = ()
+def _init_for_owlready2():
+  global _entity_classes
+  import owlready2
+  _entity_classes = (owlready2.ThingClass, owlready2.Thing, owlready2.PropertyClass)
+  import editobj3.observe
+  editobj3.observe._has_owlready2 = True
+  
 PROPERTY_TYPE_NAMES      = {"property", "getset_descriptor"}
 IGNORED_ATTRS            = {"__weakref__", "__abstractmethods__"}
 BOOL_ATTRS               = {"visible", "hidden", "active"}
@@ -86,6 +94,7 @@ class Attribute(object):
     self.remove_method   = remove_method
     self.reorder_method  = reorder_method
     self.has_item_method = has_item_method
+    self.allow_none      = False
     
     if (self.get_method and (self.get_method != "auto")) or (self.set_method and (self.set_method != "auto")):
       self.is_property = True
@@ -291,13 +300,14 @@ value by calling various methods of the class description.
     self.label            = None
     self.details          = None
     self.constructor      = None
-    #inherited_classes = getattr(klass, "__mro__", None) or klass.mro()
     if not object is inherited_classes[-1]: inherited_classes = inherited_classes + [object]
     self.inherited_descrs = [self._get_parent_description(klass) for klass in inherited_classes[1:]]
     self.inherited_descrs.insert(0, self)
     
     self.attributes.update(self.search_attributes(klass))
     
+    self.is_owl_entity = isinstance(klass, _entity_classes)
+    
   def create_attribute(self, name):
     if name in self.attributes: return self.attributes[name]
     for descr in self.inherited_descrs:
@@ -305,40 +315,8 @@ value by calling various methods of the class description.
         attribute = descr.attributes[name].copy()
         break
     else: attribute = Attribute(name)
-    #self.attributes[name] = attribute
     return attribute
     
-  # def search_attributes(self):
-  #   for attr in dir(self.klass):
-  #     if attr in IGNORED_ATTRS: continue
-  #     kval = getattr(self.klass, attr)
-      
-  #     if   type(kval).__name__ in PROPERTY_TYPE_NAMES:
-  #       attribute             = self.create_attribute(attr)
-  #       attribute.is_property = True
-  #       attribute.optional    = False
-  #       if isinstance(kval, property):
-  #         if not kval.fset: attribute.set_method = None
-  #         if not kval.fget: attribute.get_method = None
-  #       else:
-  #         if not kval.__set__: attribute.set_method = None
-  #         if not kval.__get__: attribute.get_method = None
-          
-  #     elif attr.startswith("set") and (len(attr) > 3) and _method_has_nb_args(kval, 2):
-  #       if attr[3] == "_": attr2 = attr[4:]
-  #       else:              attr2 = attr[3].lower() + attr[4:]
-  #       attribute             = self.create_attribute(attr2)
-  #       attribute.set_method  = attr
-  #       attribute.is_property = True
-        
-  #     elif attr.startswith("get") and (len(attr) > 3) and _method_has_nb_args(kval, 1):
-  #       if attr[3] == "_": attr2 = attr[4:]
-  #       else:              attr2 = attr[3].lower() + attr[4:]
-  #       attribute             = self.create_attribute(attr2)
-  #       attribute.get_method  = attr
-  #       attribute.is_property = True
-  #       attribute.optional    = False
-    
   def search_attributes(self, klass):
     attributes = {}
     for attr in dir(klass):
@@ -413,7 +391,7 @@ Example of a FormConstructor asking the user for a "name" argument:
 :param constructor: a Constructor object, a FormConstructor subclass, or None for using the class itself as a constructor."""
     self.constructor = constructor
     
-  #def def_attr(self, attr, field_class = "auto", unit = "auto", priority = "auto", inverse_attr = "auto", optional = "auto", get_method = "auto", set_method = "auto", addable_values = "auto", add_method = "auto", remove_method = "auto", reorder_method = "auto", has_item_method = "auto", label = None):
+  #def def_attr(self, attr, field_class = "auto", unit = "auto", priority = "auto", inverse_attr = "auto", optional = "auto", get_method = "auto", set_method = "auto", addable_values = "auto", add_method = "auto", remove_method = "auto", reorder_method = "auto", has_item_method = "auto", label = None, allow_none = False):
   def def_attr(self, attr, field_class = 0, **kargs):
     """def_attr(attr, field_class = "auto", unit = "auto", priority = "auto", inverse_attr = "auto", optional = "auto", get_method = "auto", set_method = "auto", addable_values = "auto", add_method = "auto", remove_method = "auto", reorder_method = "auto", has_item_method = "auto", label = None)
 
@@ -800,7 +778,7 @@ Defines an attribute.
 :param has_item_method: the method for testing the presence of items in the attribute's value.
 :param label: the label for displaying the attribute (default to the attribute name).
 
-All \*_method parameters can be a method name, a callable, or None (to disable the corresponding functionality).
+All method parameters can be a method name, a callable, or None (to disable the corresponding functionality).
 
 Except for the two first parameters, all parameters to def_attr() must be given by name, for example:
 
@@ -898,10 +876,14 @@ class ObjectPackAttribute(Attribute):
     for i in range(len(pack.objects)):
       if self.name in pack.attrs[i]:
         description_for_object(pack.objects[i])._get_attribute(self.name).set_value_for(pack.objects[i], value)
-        
+
+  def __getitem__(self, index): return self
+
+  
 class ObjectPackDescription(object):
   attributes       = {} # For def_attr
   inherited_descrs = []
+  is_owl_entity    = False
   def icon_filename_for(self, pack):
     icon_filenames = set()
     for o in pack.objects:
